==> mu11ksubb.db_2.0.2.tar.gz: mu11ksubb.db/man/mu11ksubb_dbconn.Rd <==
\name{mu11ksubb_dbconn}

\alias{mu11ksubb_dbconn}
\alias{mu11ksubb_dbfile}
\alias{mu11ksubb_dbschema}
\alias{mu11ksubb_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  mu11ksubb_dbconn()
  mu11ksubb_dbfile()
  mu11ksubb_dbschema(file="", show.indices=FALSE)
  mu11ksubb_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{mu11ksubb_dbconn} returns a connection object to the package
  annotation DB.
  IMPORTANT: Don't call \code{\link[DBI]{dbDisconnect}} on the connection
  object returned by \code{mu11ksubb_dbconn} or you will
  break all the \code{\link[AnnotationDbi]{AnnDbObj}} objects defined in this package!

  \code{mu11ksubb_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{mu11ksubb_dbschema} prints the schema definition of the
  package annotation DB.

  \code{mu11ksubb_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{mu11ksubb_dbconn}: a DBIConnection object representing an open
  connection to the package annotation DB.

  \code{mu11ksubb_dbfile}: a character string with the path to the
  package annotation DB.

  \code{mu11ksubb_dbschema}: none (invisible \code{NULL}).

  \code{mu11ksubb_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI]{dbGetQuery}},
  \code{\link[DBI]{dbConnect}},
  \code{\link[AnnotationDbi]{dbconn}},
  \code{\link[AnnotationDbi]{dbfile}},
  \code{\link[AnnotationDbi]{dbschema}},
  \code{\link[AnnotationDbi]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(mu11ksubb_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by mu11ksubb_dbconn() was created with:
  dbConnect(SQLite(), dbname=mu11ksubb_dbfile(), cache_size=64000, synchronous=0)

  mu11ksubb_dbschema()

  mu11ksubb_dbInfo()
}

\keyword{utilities}
\keyword{datasets}

==> mu11ksubb.db_2.4.1.tar.gz: mu11ksubb.db/man/mu11ksubb_dbconn.Rd <==

\name{mu11ksubb_dbconn}

\alias{mu11ksubb_dbconn}
\alias{mu11ksubb_dbfile}
\alias{mu11ksubb_dbschema}
\alias{mu11ksubb_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  mu11ksubb_dbconn()
  mu11ksubb_dbfile()
  mu11ksubb_dbschema(file="", show.indices=FALSE)
  mu11ksubb_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{mu11ksubb_dbconn} returns a connection object to the
  package annotation DB.  IMPORTANT: Don't call
  \code{\link[DBI:dbConnect]{dbDisconnect}} on the connection object
  returned by \code{mu11ksubb_dbconn} or you will break all the
  \code{\link[AnnotationDbi:AnnDbObj-class]{AnnDbObj}} objects defined
  in this package!

  \code{mu11ksubb_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{mu11ksubb_dbschema} prints the schema definition of the
  package annotation DB.

  \code{mu11ksubb_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{mu11ksubb_dbconn}: a DBIConnection object representing an
  open connection to the package annotation DB.

  \code{mu11ksubb_dbfile}: a character string with the path to the
  package annotation DB.

  \code{mu11ksubb_dbschema}: none (invisible \code{NULL}).

  \code{mu11ksubb_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI:dbSendQuery]{dbGetQuery}},
  \code{\link[DBI:dbConnect]{dbConnect}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbconn}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbfile}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbschema}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(mu11ksubb_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by mu11ksubb_dbconn() was
  ## created with:
  dbConnect(SQLite(), dbname=mu11ksubb_dbfile(), cache_size=64000,
  synchronous=0)

  mu11ksubb_dbschema()

  mu11ksubb_dbInfo()
}

\keyword{utilities}
\keyword{datasets}
